@@ -208,7 +208,9 @@ def get_plugin_and_hadoop_version(request):
     req.update(request.POST)
     if req.get("plugin_name"):
         plugin_name = req["plugin_name"]
-        hadoop_version = req["hadoop_version"]
+        hadoop_version = (
+            req.get("plugin_version", None) or req["hadoop_version"]
+        )
     return plugin_name, hadoop_version
 
 
@@ -249,8 +251,8 @@ def populate_image_choices(self, request, context, empty_choice=False):
 
 class PluginAndVersionMixin(object):
     def _generate_plugin_version_fields(self, sahara):
-        plugins = sahara.plugins.list()
-        plugins = filter(is_plugin_not_hidden_for_user, plugins)
+        plugins = [p for p in sahara.plugins.list()
+                   if is_plugin_not_hidden_for_user(p)]
         plugin_choices = [(plugin.name, plugin.title) for plugin in plugins]
 
         self.fields["plugin_name"] = forms.ChoiceField(
